pub struct DocumentBody {
pub id: String,
pub title: Option<String>,
pub block_styles: Vec<BlockStyle>,
pub pages: Vec<Page>,
}Expand description
The document child of the root zenith node.
Named DocumentBody to avoid clashing with the root Document type.
Fields
id: Stringtitle: Option<String>block_styles: Vec<BlockStyle>Per-role markdown block style declarations at document scope. Empty when
no block role="…" children are declared on the document node. Lowest
cascade precedence: document < page < text. Data-only in this unit.
pages: Vec<Page>Trait Implementations
Sourceimpl Clone for DocumentBody
impl Clone for DocumentBody
Sourcefn clone(&self) -> DocumentBody
fn clone(&self) -> DocumentBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocumentBody
impl Debug for DocumentBody
Sourceimpl PartialEq for DocumentBody
impl PartialEq for DocumentBody
Sourcefn eq(&self, other: &DocumentBody) -> bool
fn eq(&self, other: &DocumentBody) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DocumentBody