Module value

Module value 

Dimension, unit, and property-value types.

Structs

Dimension
A value that carries a numeric magnitude and a measurement unit.

Enums

PropertyValue
A property value that is either a token reference or a raw literal string.
Unit
A unit of measurement used in .zen documents.

Functions

dim_to_px
Convert a dimension value + unit to pixels.