pub struct NodeContentDescriptor {
pub description: &'static str,
pub example: &'static str,
}Expand description
Full content descriptor for a node kind that accepts authorable child content.
Returned by node_content.
Fields
description: &'static strShort prose description of what the child content represents.
example: &'static strA minimal, syntactically correct example of the child content written inside the parent node’s block (without the surrounding node wrapper).