pub struct ResolvedShadowLayer {
pub dx: f64,
pub dy: f64,
pub blur: f64,
pub color_token: String,
}Expand description
A single resolved shadow layer: offsets and blur (pixels) plus the id of the color token this layer renders with.
Fields
dx: f64dy: f64blur: f64color_token: StringTrait Implementations
Sourceimpl Clone for ResolvedShadowLayer
impl Clone for ResolvedShadowLayer
Sourcefn clone(&self) -> ResolvedShadowLayer
fn clone(&self) -> ResolvedShadowLayer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedShadowLayer
impl Debug for ResolvedShadowLayer
Sourceimpl PartialEq for ResolvedShadowLayer
impl PartialEq for ResolvedShadowLayer
Sourcefn eq(&self, other: &ResolvedShadowLayer) -> bool
fn eq(&self, other: &ResolvedShadowLayer) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ResolvedShadowLayer