Dimension, unit, and property-value types.
Structs
- Dimension
- A value that carries a numeric magnitude and a measurement unit.
Enums
- Property
Value - A property value that is either a token reference or a raw literal string.
- Unit
- A unit of measurement used in
.zendocuments.
Functions
- dim_
to_ px - Convert a dimension value + unit to pixels.